@@ -108,6 +108,11 @@ $Thruk::Backend::Provider::Livestatus::extra_service_columns = [qw/
     contacts contact_groups long_plugin_output comments_with_info downtimes_with_info host_contacts host_contact_groups last_update
     last_hard_state last_hard_state_change last_state
 /];
+$Thruk::Backend::Provider::Livestatus::ref_service_columns = [ @{$Thruk::Backend::Provider::Livestatus::default_service_columns}, @{$Thruk::Backend::Provider::Livestatus::extra_service_columns} ];
+push @{$Thruk::Backend::Provider::Livestatus::ref_service_columns}, map { "host_".$_ } @{$Thruk::Backend::Provider::Livestatus::default_host_columns};
+push @{$Thruk::Backend::Provider::Livestatus::ref_service_columns}, map { "host_".$_ } @{$Thruk::Backend::Provider::Livestatus::extra_host_columns};
+$Thruk::Backend::Provider::Livestatus::ref_service_columns = Thruk::Base::array_uniq($Thruk::Backend::Provider::Livestatus::ref_service_columns);
+
 $Thruk::Backend::Provider::Livestatus::extra_servicegroup_columns = [qw/
     num_services
     num_services_hard_crit num_services_hard_ok num_services_hard_unknown num_services_hard_warn
